#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ResourceRelatedItem import ResourceRelatedItem


class AlipayInsCooperationResourceUrlBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsCooperationResourceUrlBatchqueryResponse, self).__init__()
        self._resource_items = None
        self._response_time = None
        self._result_code = None
        self._result_desc = None

    @property
    def resource_items(self):
        return self._resource_items

    @resource_items.setter
    def resource_items(self, value):
        if isinstance(value, list):
            self._resource_items = list()
            for i in value:
                if isinstance(i, ResourceRelatedItem):
                    self._resource_items.append(i)
                else:
                    self._resource_items.append(ResourceRelatedItem.from_alipay_dict(i))
    @property
    def response_time(self):
        return self._response_time

    @response_time.setter
    def response_time(self, value):
        self._response_time = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_desc(self):
        return self._result_desc

    @result_desc.setter
    def result_desc(self, value):
        self._result_desc = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsCooperationResourceUrlBatchqueryResponse, self).parse_response_content(response_content)
        if 'resource_items' in response:
            self.resource_items = response['resource_items']
        if 'response_time' in response:
            self.response_time = response['response_time']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_desc' in response:
            self.result_desc = response['result_desc']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingActivityOrdervoucherAssociateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingActivityOrdervoucherAssociateResponse, self).__init__()
        self._associate_time = None

    @property
    def associate_time(self):
        return self._associate_time

    @associate_time.setter
    def associate_time(self, value):
        self._associate_time = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingActivityOrdervoucherAssociateResponse, self).parse_response_content(response_content)
        if 'associate_time' in response:
            self.associate_time = response['associate_time']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BankLogTransferFormNew(object):

    def __init__(self):
        self._charge_amount = None
        self._chargeccy = None
        self._crossccy_flag = None
        self._exchange = None
        self._id = None
        self._inst_id = None
        self._ip_role_id = None
        self._is_recharge_receipt = None
        self._memo = None
        self._target = None
        self._trans_dt = None

    @property
    def charge_amount(self):
        return self._charge_amount

    @charge_amount.setter
    def charge_amount(self, value):
        self._charge_amount = value
    @property
    def chargeccy(self):
        return self._chargeccy

    @chargeccy.setter
    def chargeccy(self, value):
        self._chargeccy = value
    @property
    def crossccy_flag(self):
        return self._crossccy_flag

    @crossccy_flag.setter
    def crossccy_flag(self, value):
        self._crossccy_flag = value
    @property
    def exchange(self):
        return self._exchange

    @exchange.setter
    def exchange(self, value):
        self._exchange = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def is_recharge_receipt(self):
        return self._is_recharge_receipt

    @is_recharge_receipt.setter
    def is_recharge_receipt(self, value):
        self._is_recharge_receipt = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def target(self):
        return self._target

    @target.setter
    def target(self, value):
        self._target = value
    @property
    def trans_dt(self):
        return self._trans_dt

    @trans_dt.setter
    def trans_dt(self, value):
        self._trans_dt = value


    def to_alipay_dict(self):
        params = dict()
        if self.charge_amount:
            if hasattr(self.charge_amount, 'to_alipay_dict'):
                params['charge_amount'] = self.charge_amount.to_alipay_dict()
            else:
                params['charge_amount'] = self.charge_amount
        if self.chargeccy:
            if hasattr(self.chargeccy, 'to_alipay_dict'):
                params['chargeccy'] = self.chargeccy.to_alipay_dict()
            else:
                params['chargeccy'] = self.chargeccy
        if self.crossccy_flag:
            if hasattr(self.crossccy_flag, 'to_alipay_dict'):
                params['crossccy_flag'] = self.crossccy_flag.to_alipay_dict()
            else:
                params['crossccy_flag'] = self.crossccy_flag
        if self.exchange:
            if hasattr(self.exchange, 'to_alipay_dict'):
                params['exchange'] = self.exchange.to_alipay_dict()
            else:
                params['exchange'] = self.exchange
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.is_recharge_receipt:
            if hasattr(self.is_recharge_receipt, 'to_alipay_dict'):
                params['is_recharge_receipt'] = self.is_recharge_receipt.to_alipay_dict()
            else:
                params['is_recharge_receipt'] = self.is_recharge_receipt
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.target:
            if hasattr(self.target, 'to_alipay_dict'):
                params['target'] = self.target.to_alipay_dict()
            else:
                params['target'] = self.target
        if self.trans_dt:
            if hasattr(self.trans_dt, 'to_alipay_dict'):
                params['trans_dt'] = self.trans_dt.to_alipay_dict()
            else:
                params['trans_dt'] = self.trans_dt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BankLogTransferFormNew()
        if 'charge_amount' in d:
            o.charge_amount = d['charge_amount']
        if 'chargeccy' in d:
            o.chargeccy = d['chargeccy']
        if 'crossccy_flag' in d:
            o.crossccy_flag = d['crossccy_flag']
        if 'exchange' in d:
            o.exchange = d['exchange']
        if 'id' in d:
            o.id = d['id']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'is_recharge_receipt' in d:
            o.is_recharge_receipt = d['is_recharge_receipt']
        if 'memo' in d:
            o.memo = d['memo']
        if 'target' in d:
            o.target = d['target']
        if 'trans_dt' in d:
            o.trans_dt = d['trans_dt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ExtInfos import ExtInfos
from alipay.aop.api.domain.MerchantIDInfo import MerchantIDInfo
from alipay.aop.api.domain.UserDInfo import UserDInfo


class AlipayPcreditHuabeiSpayAuthConsultModel(object):

    def __init__(self):
        self._asset_type_code = None
        self._biz_type = None
        self._business_code = None
        self._ext_infos = None
        self._fee_rate_percent = None
        self._fee_taker_role = None
        self._link_mode = None
        self._merchant = None
        self._payment_mode = None
        self._receive_mode = None
        self._total_install_num = None
        self._total_payment_amount = None
        self._user = None
        self._user_id = None

    @property
    def asset_type_code(self):
        return self._asset_type_code

    @asset_type_code.setter
    def asset_type_code(self, value):
        self._asset_type_code = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def business_code(self):
        return self._business_code

    @business_code.setter
    def business_code(self, value):
        self._business_code = value
    @property
    def ext_infos(self):
        return self._ext_infos

    @ext_infos.setter
    def ext_infos(self, value):
        if isinstance(value, ExtInfos):
            self._ext_infos = value
        else:
            self._ext_infos = ExtInfos.from_alipay_dict(value)
    @property
    def fee_rate_percent(self):
        return self._fee_rate_percent

    @fee_rate_percent.setter
    def fee_rate_percent(self, value):
        self._fee_rate_percent = value
    @property
    def fee_taker_role(self):
        return self._fee_taker_role

    @fee_taker_role.setter
    def fee_taker_role(self, value):
        self._fee_taker_role = value
    @property
    def link_mode(self):
        return self._link_mode

    @link_mode.setter
    def link_mode(self, value):
        self._link_mode = value
    @property
    def merchant(self):
        return self._merchant

    @merchant.setter
    def merchant(self, value):
        if isinstance(value, MerchantIDInfo):
            self._merchant = value
        else:
            self._merchant = MerchantIDInfo.from_alipay_dict(value)
    @property
    def payment_mode(self):
        return self._payment_mode

    @payment_mode.setter
    def payment_mode(self, value):
        self._payment_mode = value
    @property
    def receive_mode(self):
        return self._receive_mode

    @receive_mode.setter
    def receive_mode(self, value):
        self._receive_mode = value
    @property
    def total_install_num(self):
        return self._total_install_num

    @total_install_num.setter
    def total_install_num(self, value):
        self._total_install_num = value
    @property
    def total_payment_amount(self):
        return self._total_payment_amount

    @total_payment_amount.setter
    def total_payment_amount(self, value):
        self._total_payment_amount = value
    @property
    def user(self):
        return self._user

    @user.setter
    def user(self, value):
        if isinstance(value, UserDInfo):
            self._user = value
        else:
            self._user = UserDInfo.from_alipay_dict(value)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_type_code:
            if hasattr(self.asset_type_code, 'to_alipay_dict'):
                params['asset_type_code'] = self.asset_type_code.to_alipay_dict()
            else:
                params['asset_type_code'] = self.asset_type_code
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.business_code:
            if hasattr(self.business_code, 'to_alipay_dict'):
                params['business_code'] = self.business_code.to_alipay_dict()
            else:
                params['business_code'] = self.business_code
        if self.ext_infos:
            if hasattr(self.ext_infos, 'to_alipay_dict'):
                params['ext_infos'] = self.ext_infos.to_alipay_dict()
            else:
                params['ext_infos'] = self.ext_infos
        if self.fee_rate_percent:
            if hasattr(self.fee_rate_percent, 'to_alipay_dict'):
                params['fee_rate_percent'] = self.fee_rate_percent.to_alipay_dict()
            else:
                params['fee_rate_percent'] = self.fee_rate_percent
        if self.fee_taker_role:
            if hasattr(self.fee_taker_role, 'to_alipay_dict'):
                params['fee_taker_role'] = self.fee_taker_role.to_alipay_dict()
            else:
                params['fee_taker_role'] = self.fee_taker_role
        if self.link_mode:
            if hasattr(self.link_mode, 'to_alipay_dict'):
                params['link_mode'] = self.link_mode.to_alipay_dict()
            else:
                params['link_mode'] = self.link_mode
        if self.merchant:
            if hasattr(self.merchant, 'to_alipay_dict'):
                params['merchant'] = self.merchant.to_alipay_dict()
            else:
                params['merchant'] = self.merchant
        if self.payment_mode:
            if hasattr(self.payment_mode, 'to_alipay_dict'):
                params['payment_mode'] = self.payment_mode.to_alipay_dict()
            else:
                params['payment_mode'] = self.payment_mode
        if self.receive_mode:
            if hasattr(self.receive_mode, 'to_alipay_dict'):
                params['receive_mode'] = self.receive_mode.to_alipay_dict()
            else:
                params['receive_mode'] = self.receive_mode
        if self.total_install_num:
            if hasattr(self.total_install_num, 'to_alipay_dict'):
                params['total_install_num'] = self.total_install_num.to_alipay_dict()
            else:
                params['total_install_num'] = self.total_install_num
        if self.total_payment_amount:
            if hasattr(self.total_payment_amount, 'to_alipay_dict'):
                params['total_payment_amount'] = self.total_payment_amount.to_alipay_dict()
            else:
                params['total_payment_amount'] = self.total_payment_amount
        if self.user:
            if hasattr(self.user, 'to_alipay_dict'):
                params['user'] = self.user.to_alipay_dict()
            else:
                params['user'] = self.user
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiSpayAuthConsultModel()
        if 'asset_type_code' in d:
            o.asset_type_code = d['asset_type_code']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'business_code' in d:
            o.business_code = d['business_code']
        if 'ext_infos' in d:
            o.ext_infos = d['ext_infos']
        if 'fee_rate_percent' in d:
            o.fee_rate_percent = d['fee_rate_percent']
        if 'fee_taker_role' in d:
            o.fee_taker_role = d['fee_taker_role']
        if 'link_mode' in d:
            o.link_mode = d['link_mode']
        if 'merchant' in d:
            o.merchant = d['merchant']
        if 'payment_mode' in d:
            o.payment_mode = d['payment_mode']
        if 'receive_mode' in d:
            o.receive_mode = d['receive_mode']
        if 'total_install_num' in d:
            o.total_install_num = d['total_install_num']
        if 'total_payment_amount' in d:
            o.total_payment_amount = d['total_payment_amount']
        if 'user' in d:
            o.user = d['user']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayChinareModelResult(object):

    def __init__(self):
        self._id = None
        self._rule_id = None
        self._rule_result = None
        self._trans_id = None

    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def rule_id(self):
        return self._rule_id

    @rule_id.setter
    def rule_id(self, value):
        self._rule_id = value
    @property
    def rule_result(self):
        return self._rule_result

    @rule_result.setter
    def rule_result(self, value):
        self._rule_result = value
    @property
    def trans_id(self):
        return self._trans_id

    @trans_id.setter
    def trans_id(self, value):
        self._trans_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.rule_id:
            if hasattr(self.rule_id, 'to_alipay_dict'):
                params['rule_id'] = self.rule_id.to_alipay_dict()
            else:
                params['rule_id'] = self.rule_id
        if self.rule_result:
            if hasattr(self.rule_result, 'to_alipay_dict'):
                params['rule_result'] = self.rule_result.to_alipay_dict()
            else:
                params['rule_result'] = self.rule_result
        if self.trans_id:
            if hasattr(self.trans_id, 'to_alipay_dict'):
                params['trans_id'] = self.trans_id.to_alipay_dict()
            else:
                params['trans_id'] = self.trans_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayChinareModelResult()
        if 'id' in d:
            o.id = d['id']
        if 'rule_id' in d:
            o.rule_id = d['rule_id']
        if 'rule_result' in d:
            o.rule_result = d['rule_result']
        if 'trans_id' in d:
            o.trans_id = d['trans_id']
        return o


